==> haskell-tree-diff-0.3.0.1-112-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tree-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tree-diff
version:              0.3.0.1
visibility:           public
id:                   tree-diff-0.3.0.1-KlM6IgXHT4h7YaFoU9ns75
key:                  tree-diff-0.3.0.1-KlM6IgXHT4h7YaFoU9ns75
license:              GPL-2.0-or-later
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/tree-diff
synopsis:             Diffing of (expression) trees.
description:
    Common diff algorithm works on list structures:

    @
    diff :: Eq a => [a] -> [a] -> [Edit a]
    @

    This package works on trees.

    @
    treeDiff :: Eq a => Tree a -> Tree a -> Edit (EditTree a)
    @

    This package also provides a way to diff arbitrary ADTs,
    using @Generics@-derivable helpers.

    This package differs from <http://hackage.haskell.org/package/gdiff gdiff>,
    in a two ways: @tree-diff@ doesn'\''t have patch function,
    and the "edit-script" is a tree itself, which is useful for pretty-printing.

    @
    >>> prettyEditExpr $ ediff (Foo 42 [True, False] "old") (Foo 42 [False, False, True] "new")
    Foo
    \  {fooBool = [-True, +False, False, +True],
    \   fooInt = 42,
    \   fooString = -"old" +"new"}
    @

category:             Data, Testing
abi:                  0713d34faeb1730f0fd1560daa75cf08
exposed:              True
exposed-modules:
    Data.TreeDiff Data.TreeDiff.Class Data.TreeDiff.Expr
    Data.TreeDiff.Golden Data.TreeDiff.List Data.TreeDiff.OMap
    Data.TreeDiff.Parser Data.TreeDiff.Pretty Data.TreeDiff.QuickCheck
    Data.TreeDiff.Tree

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tree-diff-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tree-diff-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tree-diff-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tree-diff
hs-libraries:         HStree-diff-0.3.0.1-KlM6IgXHT4h7YaFoU9ns75
depends:
    QuickCheck-2.14.3-3PB7cbCGvbeCmx5SHgwMna
    aeson-2.1.2.1-Ex7WnNUT1auEGSF1Md5zyM
    ansi-terminal-1.0-LkJ9SxmfbHcAL1Z7MEt8xc
    ansi-wl-pprint-0.6.9-JiLCTD1fQOjCX9bEtQhD6h base-4.17.2.1
    base-compat-0.12.2-3peTS4EQIw912qC0ETmbL5 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.0
    hashable-1.4.4.0-G3df7eBPFu1LRujEcYqf5c parsec-3.1.16.1
    parsers-0.12.12-9BwrsDP3JpDKedhfp7gn2c pretty-1.1.3.6
    primitive-0.8.0.0-GOwpVXsLqFV9QZOjtUgUYN
    scientific-0.3.7.0-CCWbwGLTUrCAfmDn1czSkZ
    semialign-1.3-Fv2FmxBduan6lzTWpN3T8y
    strict-0.5-3DvG350y6ApJx5vMTU0yCK
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    these-1.2-KSPgVeLVqZUFMLEkZkyMkA time-1.12.2
    unordered-containers-0.2.20-EFINKuAnn2VCsrMAVqSNI6
    uuid-types-1.0.6-4YVWNNyX5qH4Fj0MVDTTwI
    vector-0.13.1.0-KSX0XQMPS0MKwOGi5hYJAY

haddock-interfaces:   /usr/share/doc/haskell-tree-diff/html/tree-diff.haddock
haddock-html:         /usr/share/doc/haskell-tree-diff/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tree-diff-0.3.0.1-113-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tree-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tree-diff
version:              0.3.0.1
visibility:           public
id:                   tree-diff-0.3.0.1-BAILuwDakmF6Nn1uJoqwFK
key:                  tree-diff-0.3.0.1-BAILuwDakmF6Nn1uJoqwFK
license:              GPL-2.0-or-later
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/tree-diff
synopsis:             Diffing of (expression) trees.
description:
    Common diff algorithm works on list structures:

    @
    diff :: Eq a => [a] -> [a] -> [Edit a]
    @

    This package works on trees.

    @
    treeDiff :: Eq a => Tree a -> Tree a -> Edit (EditTree a)
    @

    This package also provides a way to diff arbitrary ADTs,
    using @Generics@-derivable helpers.

    This package differs from <http://hackage.haskell.org/package/gdiff gdiff>,
    in a two ways: @tree-diff@ doesn'\''t have patch function,
    and the "edit-script" is a tree itself, which is useful for pretty-printing.

    @
    >>> prettyEditExpr $ ediff (Foo 42 [True, False] "old") (Foo 42 [False, False, True] "new")
    Foo
    \  {fooBool = [-True, +False, False, +True],
    \   fooInt = 42,
    \   fooString = -"old" +"new"}
    @

category:             Data, Testing
abi:                  f47c80f25e5fca56916ca2690272954c
exposed:              True
exposed-modules:
    Data.TreeDiff Data.TreeDiff.Class Data.TreeDiff.Expr
    Data.TreeDiff.Golden Data.TreeDiff.List Data.TreeDiff.OMap
    Data.TreeDiff.Parser Data.TreeDiff.Pretty Data.TreeDiff.QuickCheck
    Data.TreeDiff.Tree

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tree-diff-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tree-diff-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tree-diff-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tree-diff
hs-libraries:         HStree-diff-0.3.0.1-BAILuwDakmF6Nn1uJoqwFK
depends:
    QuickCheck-2.14.3-H48j1VoMzL8JGNazf5xEmB
    aeson-2.1.2.1-4xKrNuS491zGhSp7DRfhkt
    ansi-terminal-1.0.2-ITeMK84EaXB5F8MZcYamKC
    ansi-wl-pprint-0.6.9-HaRNOAoQkwI3t7zJogR3fc base-4.17.2.1
    base-compat-0.12.2-3peTS4EQIw912qC0ETmbL5 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.0
    hashable-1.4.4.0-909PfscEME9DWRnST3i6i parsec-3.1.16.1
    parsers-0.12.12-BsR3JVgdIVC7709ap6exy9 pretty-1.1.3.6
    primitive-0.8.0.0-6jHRoorKHpAIZUFWkBkRow
    scientific-0.3.7.0-LbGAkLwJByt1Tv5Onvb1iB
    semialign-1.3-H3ZNhnHau0VAUy6Pm7lG50
    strict-0.5-E5NHSDjQ8KRLkg5iRCKrG4
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    these-1.2-6V88oQzbOKXHWOGC8gEnZL time-1.12.2
    unordered-containers-0.2.20-Ko0oshTaIwM77y5vt748zM
    uuid-types-1.0.6-8dSaI2RksSp7ZAnMFvyKqC
    vector-0.13.1.0-DtCykb5ubgAP5TmqHJqsZ

haddock-interfaces:   /usr/share/doc/haskell-tree-diff/html/tree-diff.haddock
haddock-html:         /usr/share/doc/haskell-tree-diff/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
